| Safe Haskell | Safe-Infered |
|---|
IDE.Find
Description
The toolbar for searching and replacing in a text buffer
Documentation
Constructors
| FindState | |
Fields
| |
leksah-0.12.1.2: Haskell IDE written in Haskell
| Safe Haskell | Safe-Infered |
|---|
IDE.Find
Description
The toolbar for searching and replacing in a text buffer
Constructors
| FindState | |
Fields
| |