| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
IDE.Pane.Workspace
Description
The pane of the IDE that shows the cabal packages in the workspace and their build targets
- data WorkspaceState = WorkspaceState
- data IDEWorkspace
- updateWorkspace :: Bool -> Bool -> IDEAction
- getWorkspace :: Maybe PanePath -> IDEM IDEWorkspace
- showWorkspace :: IDEAction
Documentation
data WorkspaceState Source
The additional state used when recovering the pane (none, the packages and their targets come from the IDE state)
Constructors
| WorkspaceState |
data IDEWorkspace Source
The representation of the workspace pane
Arguments
| :: Bool | Show the pane if it is open and a workspace is loaded |
| -> Bool | Empty the |
| -> IDEAction |
Repopulates the workspace pane with the current packages (if the pane is open)
getWorkspace :: Maybe PanePath -> IDEM IDEWorkspace Source
Get the workspace pane
showWorkspace :: IDEAction Source
Show the workspace pane